Module types

Module types 

Definitions of traits required for handling container Images.

Reference:

Types Implemented in Go

We are not going to define the types matching one to one above, but instead, the idea is to have Interface definitions that would broadly achieve everything that the interfaces above achieve.

Modules

errors

Structs

ImageInspect
A struct representing Inspect output (Something like ‘docker inspect’, ‘skopeo inspect’)
ImageManifest
A struct representing Image Manfest

Traits

Image
A trait that should be implemented by all Images.
ImageReference
A trait that should be implemented by All Image References
ImageSource
A trait that should be implemented by All Image Sources.
ImageTransport
A trait that is to be implemented by All supported Image Transports

Type Aliases

ImageResult
A Result of operations related to handling Images