Definitions of traits required for handling container Images.
Reference:
We are not going to define the types matching one to one above, but instead, the idea is to have Interface definitions that would broadly achieve everything that the interfaces above achieve.
Modules
Structs
- Image
Inspect - A struct representing Inspect output (Something like ‘docker inspect’, ‘skopeo inspect’)
- Image
Manifest - A struct representing Image Manfest
Traits
- Image
- A trait that should be implemented by all Images.
- Image
Reference - A trait that should be implemented by All Image References
- Image
Source - A trait that should be implemented by All Image Sources.
- Image
Transport - A trait that is to be implemented by All supported Image Transports
Type Aliases
- Image
Result - A Result of operations related to handling Images